@@ -2,6 +2,7 @@
 __version__ = '0.1.0'
 
 import random
+import sys
 
 def build_card():
     total_cards = []
@@ -21,17 +22,27 @@ def get_random_card():
     random.shuffle(cards)
     return cards
 
-def main():
+def main(piece):
     cards = get_random_card()
-    n = 0
+    n = 1
     for i, item in enumerate(cards):
-        if i % 13 == 0 or i == 0:
+        if i % piece == 0 or i == 0:
             print()
-            print(str.format("Player {}:", n), end=' ')
+            print(str.format("Player {: 2}:", n), end=' ')
             n += 1
         d = item[1]+item[0]
         s = str.ljust(d, 3, ' ')
         print(s, end=" ")
 
+def run():
+    argv = sys.argv[1:]
+    piece = int(argv[0]) if argv else 4
+    
+    p = int(52 / piece)
+    if 52 % piece:
+        main(p+1)
+    else:
+        main(p)
+
 if __name__ == "__main__":
-    main()
+    run()
\ No newline at end of file
